==> raml-client-2.0.7.tgz: package/test/client/basic/basic.js <==
const { expect } = require('chai');
const ramlClient = require('../../../src');

describe('Basic Auth RAML', () => {
  let client;
  let API;

  before(() => {
    API = ramlClient({
      redirectUri: 'http://localhost:5000/resources/oauth.html',
      proxy: 'http://localhost:5001/myproxy/',
      authorization: 'my token',
      xhr: XMLHttpRequest,
      sync: true,
      ramlQueryBuilder: ({ groupId, assetId, version }) => `http://localhost:5001/assets/${groupId}/${assetId}/${version}/api/json`
    });
  });

  before(() => (
    API.createClient('basic', 'basic', 'api.raml', '1.0.0', { sync: false })
      .then((result) => {
        client = result;

        expect(result.toDescription()).to.eql('Client has been successfully created');
      })
  ));

  it('creates the client', () => {
    expect(client).to.exist;
    expect(global.basic).to.exist;
  });

  it('does an unauthorized api call', () => (
    client.content.get({ search: 'my search' })
      .then((response) => {
        expect(response.body.data).to.eql(['my search']);
      })
  ));

  context('authorized', () => {
    before(() => API.authenticate(client, { username: 'username', password: 'password' }));

    it('has the token assigned', () => {
      expect(client['!client'].authentication['Basic Authentication'].username).to.be.eql('username');
      expect(client['!client'].authentication['Basic Authentication'].password).to.be.eql('password');
    });

    it('does an authorized api call', () => (
      client.authorized.get()
        .then((response) => {
          expect(response.body.header).to.exist;
        })
    ));
  });
});

==> raml-client-2.1.0.tgz: package/test/client/basic/basic.js <==
const { expect } = require('chai');
const ramlClient = require('../../../src');

describe('Basic Auth RAML', () => {
  let client;
  let API;

  before(() => {
    API = ramlClient({
      redirectUri: 'http://localhost:5000/resources/oauth.html',
      proxy: 'http://localhost:5001/myproxy/',
      authorization: 'my token',
      xhr: XMLHttpRequest,
      sync: true,
      ramlQueryBuilder: ({ groupId, assetId, version }) => `http://localhost:5001/assets/${groupId}/${assetId}/${version}/api/json`
    });
  });

  before(() => (
    API.createClient('basic', 'api.raml', '1.0.0', { sync: false })
      .then((result) => {
        client = result;

        expect(result.toDescription()).to.eql('Client has been successfully created');
      })
  ));

  it('creates the client', () => {
    expect(client).to.exist;
    expect(global.basic).to.not.exist;
  });

  it('does an unauthorized api call', () => (
    client.content.get({ search: 'my search' })
      .then((response) => {
        expect(response.body.data).to.eql(['my search']);
      })
  ));

  context('authorized', () => {
    before(() => API.authenticate(client, { username: 'username', password: 'password' }));

    it('has the token assigned', () => {
      expect(client['!client'].authentication['Basic Authentication'].username).to.be.eql('username');
      expect(client['!client'].authentication['Basic Authentication'].password).to.be.eql('password');
    });

    it('does an authorized api call', () => (
      client.authorized.get()
        .then((response) => {
          expect(response.body.header).to.exist;
        })
    ));
  });
});
